@@ -8,7 +8,7 @@ using DocStringExtensions
 using LinearAlgebra
 
 import ArrayInterface
-import MacroTools: @forward
+# MacroTools dependency removed - using explicit method forwarding instead
 import Accessors: @reset
 
 # overload
@@ -212,33 +212,33 @@ include("tensor.jl")
 include("woperator.jl")
 
 export
-       IdentityOperator,
-       NullOperator,
-       ScalarOperator,
-       MatrixOperator,
-       DiagonalOperator,
-       InvertibleOperator,
-       AffineOperator,
-       AddVector,
-       FunctionOperator,
-       TensorProductOperator,
-       WOperator,
-       StaticWOperator
+    IdentityOperator,
+    NullOperator,
+    ScalarOperator,
+    MatrixOperator,
+    DiagonalOperator,
+    InvertibleOperator,
+    AffineOperator,
+    AddVector,
+    FunctionOperator,
+    TensorProductOperator,
+    WOperator,
+    StaticWOperator
 
 export update_coefficients!,
-       update_coefficients, isconstant,
-       iscached,
-       cache_operator, issquare,
-       islinear,
-       concretize,
-       isconvertible, has_adjoint,
-       has_expmv,
-       has_expmv!,
-       has_exp,
-       has_mul,
-       has_mul!,
-       has_ldiv,
-       has_ldiv!,
-       has_concretization
+    update_coefficients, isconstant,
+    iscached,
+    cache_operator, issquare,
+    islinear,
+    concretize,
+    isconvertible, has_adjoint,
+    has_expmv,
+    has_expmv!,
+    has_exp,
+    has_mul,
+    has_mul!,
+    has_ldiv,
+    has_ldiv!,
+    has_concretization
 
 end # module
